@@ -4,7 +4,6 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <KItinerary/Extractor>
 #include <KItinerary/ExtractorEngine>
 #include <KItinerary/ExtractorPostprocessor>
 #include <KItinerary/JsonLdDocument>
@@ -62,7 +61,7 @@ private Q_SLOTS:
 
         ExtractorEngine engine;
         engine.setContextDate(QDateTime(QDate(2017, 12, 29), QTime(18, 46, 2)));
-        engine.setPass(pass);
+        engine.setContent(QVariant::fromValue(pass), u"application/vnd.apple.pkpass");
         auto result = JsonLdDocument::fromJson(engine.extract());
 
         ExtractorPostprocessor postproc;
