@@ -8,15 +8,14 @@
 #include <kitinerary_version.h>
 
 #include <KItinerary/CalendarHandler>
-#include <KItinerary/Extractor>
 #include <KItinerary/ExtractorCapabilities>
 #include <KItinerary/ExtractorEngine>
-#include <KItinerary/ExtractorInput>
 #include <KItinerary/ExtractorPostprocessor>
 #include <KItinerary/ExtractorRepository>
 #include <KItinerary/JsonLdDocument>
 #include <KItinerary/MergeUtil>
 #include <KItinerary/Reservation>
+#include <KItinerary/ScriptExtractor>
 
 #include <KCalendarCore/Event>
 #include <KCalendarCore/ICalFormat>
@@ -77,12 +76,14 @@ static void printCapabilities()
 static void printExtractors()
 {
     ExtractorRepository repo;
-    for (const auto &ext : repo.allExtractors()) {
-        std::cout << qPrintable(ext.name()) << " (" << qPrintable(ExtractorInput::typeToString(ext.type()));
-        if (!ext.scriptFileName().isEmpty()) {
-            std::cout << ", " << qPrintable(ext.scriptFileName()) << ":" << qPrintable(ext.scriptFunction());
+    for (const auto &ext : repo.extractors()) {
+        std::cout << qPrintable(ext->name());
+        if (auto scriptExt = dynamic_cast<const ScriptExtractor*>(ext.get())) {
+            std::cout << " (" << qPrintable(scriptExt->mimeType()) << ", "
+                      << qPrintable(scriptExt->scriptFileName()) << ":"
+                      << qPrintable(scriptExt->scriptFunction()) << ")";
         }
-        std::cout << ")" << std::endl;
+        std::cout << std::endl;
     }
 }
 
@@ -105,7 +106,7 @@ int main(int argc, char** argv)
 
     QCommandLineOption ctxOpt({QStringLiteral("c"), QStringLiteral("context-date")}, QStringLiteral("ISO date/time for when this data has been received."), QStringLiteral("date"));
     parser.addOption(ctxOpt);
-    QCommandLineOption typeOpt({QStringLiteral("t"), QStringLiteral("type")}, QStringLiteral("Type of the input data [Email, Pdf, PkPass, ICal, Html]."), QStringLiteral("type"));
+    QCommandLineOption typeOpt({QStringLiteral("t"), QStringLiteral("type")}, QStringLiteral("Deprecated, no longer needed and ignored."), QStringLiteral("type"));
     parser.addOption(typeOpt);
     QCommandLineOption extOpt({QStringLiteral("e"), QStringLiteral("extractors")}, QStringLiteral("Additional extractors to apply."), QStringLiteral("extractors"));
     parser.addOption(extOpt);
@@ -146,7 +147,7 @@ int main(int argc, char** argv)
     postproc.setValidationEnabled(!parser.isSet(noValidationOpt));
 
     const auto files = parser.positionalArguments().isEmpty() ? QStringList(QString()) : parser.positionalArguments();
-    for (const auto arg : files) {
+    for (const auto &arg : files) {
         QFile f;
         if (!arg.isEmpty()) {
             f.setFileName(arg);
@@ -159,7 +160,6 @@ int main(int argc, char** argv)
         }
 
         auto fileName = f.fileName();
-        const auto typeArg = ExtractorInput::typeFromName(parser.value(typeOpt));
 
         engine.clear();
         engine.setContextDate(contextDt);
@@ -167,27 +167,22 @@ int main(int argc, char** argv)
         if (!parser.value(extOpt).isEmpty()) {
             const auto extNames = parser.value(extOpt).split(QLatin1Char(';'),
                                                              Qt::SkipEmptyParts);
-            std::vector<Extractor> exts;
+            std::vector<const AbstractExtractor*> exts;
             exts.reserve(extNames.size());
             for (const auto &name : extNames) {
-                const auto ext = repo.extractor(name);
+                const auto ext = repo.extractorByName(name);
                 exts.push_back(ext);
             }
             engine.setAdditionalExtractors(std::move(exts));
         }
 
-        if (typeArg == ExtractorInput::Unknown) {
-            engine.setData(f.readAll(), fileName);
-        } else {
-            engine.setData(f.readAll(), typeArg);
-        }
-
+        engine.setData(f.readAll(), fileName);
         const auto result = JsonLdDocument::fromJson(engine.extract());
         postproc.process(result);
     }
 
 
-    if (ExtractorInput::typeFromName(parser.value(formatOpt)) == ExtractorInput::ICal) {
+    if (parser.value(formatOpt).compare(QLatin1String("ical"), Qt::CaseInsensitive) == 0) {
         const auto batches = batchReservations(postproc.result());
         KCalendarCore::Calendar::Ptr cal(new KCalendarCore::MemoryCalendar(QTimeZone::systemTimeZone()));
         for (const auto &batch : batches) {
