@@ -1,18 +1,7 @@
 /*
-    Copyright (C) 2018 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2018 Volker Krause <vkrause@kde.org>
 
-    This program is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This program is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "airportdbgenerator.h"
@@ -35,6 +24,8 @@ int main(int argc, char **argv)
     parser.addOption(dbOpt);
     QCommandLineOption outputOpt({QStringLiteral("o"), QStringLiteral("output")}, QStringLiteral("Output file."), QStringLiteral("output file"));
     parser.addOption(outputOpt);
+    QCommandLineOption osmOpt({QStringLiteral("m"), QStringLiteral("osm-data")}, QStringLiteral("OSM data file."), QStringLiteral("osm file"));
+    parser.addOption(osmOpt);
     parser.addHelpOption();
     parser.process(app);
 
@@ -46,6 +37,7 @@ int main(int argc, char **argv)
 
     if (parser.value(dbOpt) == QLatin1String("airport")) {
         AirportDbGenerator gen;
+        gen.osmDb.load(parser.value(osmOpt));
         return gen.generate(&out) ? 0 : 1;
     } else if (parser.value(dbOpt) == QLatin1String("country")) {
         CountryDbGenerator gen;
