@@ -75,7 +75,8 @@ QVector<QSharedPointer<KCalendarCore::Event> > CalendarHandler::findEvents(const
         return {};
     }
 
-    QVector<KCalendarCore::Event::Ptr> events, results;
+    QVector<KCalendarCore::Event::Ptr> events;
+    QVector<KCalendarCore::Event::Ptr> results;
     const auto dt = SortUtil::startDateTime(reservation).toTimeZone(calendar->timeZone()).date();
     if (dt.isValid()) {
         // we know the exact day to search at
@@ -184,7 +185,7 @@ void CalendarHandler::fillEvent(const QVector<QVariant> &reservations, const QSh
 
     if (JsonLd::canConvert<Reservation>(reservation) && JsonLd::convert<Reservation>(reservation).reservationStatus() == Reservation::ReservationCancelled) {
         event->setTransparency(KCalendarCore::Event::Transparent);
-        event->setSummary(i18nc("canceled train/flight/loding reservation", "Canceled: %1", event->summary()));
+        event->setSummary(i18nc("canceled train/flight/loading reservation", "Canceled: %1", event->summary()));
         event->clearAlarms();
     }
 
