@@ -26,6 +26,7 @@
 #include <KItinerary/Organization>
 #include <KItinerary/Person>
 #include <KItinerary/Place>
+#include <KItinerary/ProgramMembership>
 #include <KItinerary/RentalCar>
 #include <KItinerary/Reservation>
 #include <KItinerary/Taxi>
@@ -33,7 +34,11 @@
 #include <KItinerary/TrainTrip>
 #include <KItinerary/Visit>
 
+#if HAVE_KI18N_LOCALE_DATA
+#include <KCountry>
+#else
 #include <KContacts/Address>
+#endif
 
 #include <QDebug>
 #include <QJsonArray>
@@ -157,9 +162,9 @@ void ExtractorPostprocessorPrivate::mergeOrAppend(const QVariant &elem)
 QVariant ExtractorPostprocessorPrivate::processFlightReservation(FlightReservation res) const
 {
     // expand ticketToken for IATA BCBP data
-    const auto bcbp = res.reservedTicket().value<Ticket>().ticketTokenData();
+    const auto bcbp = res.reservedTicket().value<Ticket>().ticketTokenData().toString();
     if (!bcbp.isEmpty()) {
-        const auto bcbpData = IataBcbpParser::parse(bcbp, m_contextDate.date());
+        const auto bcbpData = IataBcbpParser::parse(bcbp, m_contextDate);
         if (bcbpData.size() == 1) {
             res = JsonLdDocument::apply(bcbpData.at(0), res).value<FlightReservation>();
             // standardize on the BCBP booking reference, not some secondary one we might have in structured data for example
@@ -274,14 +279,7 @@ QDateTime ExtractorPostprocessorPrivate::processTrainTripTime(QDateTime dt, QDat
         return dt;
     }
 
-    QTimeZone tz;
-    const auto geo = station.geo();
-    const KnowledgeDb::CountryId country{station.address().addressCountry()};
-    if (geo.isValid()) {
-        tz = KnowledgeDb::toQTimeZone(KnowledgeDb::timezoneForLocation(geo.latitude(), geo.longitude(), country));
-    } else {
-        tz = KnowledgeDb::toQTimeZone(KnowledgeDb::timezoneForCountry(country));
-    }
+    const auto tz = KnowledgeDb::timezoneForLocation(station.geo().latitude(), station.geo().longitude(), station.address().addressCountry());
     if (!tz.isValid()) {
         return dt;
     }
@@ -403,12 +401,24 @@ Event ExtractorPostprocessorPrivate::processEvent(Event event) const
     return event;
 }
 
+ProgramMembership ExtractorPostprocessorPrivate::processProgramMembership(ProgramMembership program) const
+{
+    program.setProgramName(program.programName().simplified());
+     // avoid emitting spurious empty ProgramMembership objects caused by empty elements in JSON-LD/Microdata input
+    if (program.programName().isEmpty() && !program.programName().isNull()) {
+        program.setProgramName(QString());
+    }
+    program.setMember(processPerson(program.member()));
+    return program;
+}
+
 template <typename T>
 T ExtractorPostprocessorPrivate::processReservation(T res) const
 {
     res.setUnderName(processPerson(res.underName().template value<Person>()));
     res.setPotentialAction(processActions(res.potentialAction()));
     res.setReservationNumber(res.reservationNumber().trimmed());
+    res.setProgramMembershipUsed(processProgramMembership(res.programMembershipUsed()));
     return res;
 }
 
@@ -442,6 +452,20 @@ PostalAddress ExtractorPostprocessorPrivate::processAddress(PostalAddress addr,
 {
     // convert to ISO 3166-1 alpha-2 country codes
     if (addr.addressCountry().size() > 2) {
+#if HAVE_KI18N_LOCALE_DATA
+        QString alpha2Code;
+
+        // try ISO 3166-1 alpha-3, we get that e.g. from Flixbus
+        if (addr.addressCountry().size() == 3) {
+            alpha2Code = KCountry::fromAlpha3(addr.addressCountry()).alpha2();
+        }
+        if (alpha2Code.isEmpty()) {
+            alpha2Code = KCountry::fromName(addr.addressCountry()).alpha2();
+        }
+        if (!alpha2Code.isEmpty()) {
+            addr.setAddressCountry(alpha2Code);
+        }
+#else
         const auto isoCode = KContacts::Address::countryToISO(addr.addressCountry()).toUpper();
         if (!isoCode.isEmpty()) {
             addr.setAddressCountry(isoCode);
@@ -453,6 +477,7 @@ PostalAddress ExtractorPostprocessorPrivate::processAddress(PostalAddress addr,
                 addr.setAddressCountry(c.toString());
             }
         }
+#endif
     }
 
     // upper case country codes
@@ -482,10 +507,7 @@ PostalAddress ExtractorPostprocessorPrivate::processAddress(PostalAddress addr,
 #endif
 
     if (geo.isValid() && addr.addressCountry().isEmpty()) {
-        const auto isoCode = KnowledgeDb::countryForCoordinate(geo.latitude(), geo.longitude());
-        if (isoCode.isValid()) {
-            addr.setAddressCountry(isoCode.toString());
-        }
+        addr.setAddressCountry(KnowledgeDb::countryForCoordinate(geo.latitude(), geo.longitude()));
     }
 
     addr = ExtractorUtil::extractPostalCode(addr);
@@ -566,11 +588,7 @@ QDateTime ExtractorPostprocessorPrivate::processTimeForLocation(QDateTime dt, co
         return dt;
     }
 
-    QTimeZone tz;
-    if (!place.address().addressCountry().isEmpty()) {
-        tz = KnowledgeDb::toQTimeZone(KnowledgeDb::timezoneForLocation(place.geo().latitude(), place.geo().longitude(),
-                                                                       KnowledgeDb::CountryId{place.address().addressCountry()}));
-    }
+    const auto tz = KnowledgeDb::timezoneForLocation(place.geo().latitude(), place.geo().longitude(), place.address().addressCountry());
     if (!tz.isValid()) {
         return dt;
     }
