@@ -26,6 +26,7 @@ class GeoCoordinates;
 class LodgingReservation;
 class Person;
 class PostalAddress;
+class ProgramMembership;
 class RentalCar;
 class RentalCarReservation;
 class TaxiReservation;
@@ -58,6 +59,8 @@ public:
     TaxiReservation processTaxiReservation(TaxiReservation res) const;
     Event processEvent(Event event) const;
 
+    ProgramMembership processProgramMembership(ProgramMembership program) const;
+
     template <typename T> T processReservation(T res) const;
     Person processPerson(Person person) const;
     template <typename T> static T processPlace(T place);
