@@ -7,10 +7,10 @@
 #include "airportdb.h"
 #include "airportdb_p.h"
 #include "airportdb_data.cpp"
+#include "airportnametokenizer_p.h"
 #include "stringutil.h"
 
 #include <QDebug>
-#include <QRegularExpression>
 #include <QTimeZone>
 
 #include <algorithm>
@@ -43,7 +43,7 @@ QTimeZone timezoneForAirport(IataCode iataCode)
         return {};
     }
 
-    return KnowledgeDb::toQTimeZone(KnowledgeDb::timezoneForLocation((*it).coordinate.latitude, (*it).coordinate.longitude, (*it).country));
+    return KnowledgeDb::timezoneForLocation((*it).coordinate.latitude, (*it).coordinate.longitude, (*it).country.toString());
 }
 
 KnowledgeDb::CountryId countryForAirport(IataCode iataCode)
@@ -60,7 +60,9 @@ static QString normalizeFragment(const QString &s)
 {
     auto res = StringUtil::normalize(s);
     // resolve abbreviations
-    if (res == QLatin1String("intl")) return QStringLiteral("international");
+    if (res == QLatin1String("intl")) {
+        return QStringLiteral("international");
+    }
 
     return res;
 }
@@ -194,22 +196,23 @@ static void iataCodeForNameFragments(const QStringList &fragments, std::vector<I
     iataCodeForNonUniqueFragments(fragments, codes);
 }
 
-static QStringList splitToFragments(const QString &name)
+static QStringList splitToFragments(QStringView name)
 {
-    return name.split(QRegularExpression(QStringLiteral("[ 0-9/'\"\\(\\)&\\,.–„-]")),
-                      Qt::SkipEmptyParts);
+    AirportNameTokenizer tokenizer(name);
+    return tokenizer.toStringList();
 }
 
 }
 
-std::vector<KnowledgeDb::IataCode> KnowledgeDb::iataCodesFromName(const QString &name)
+std::vector<KnowledgeDb::IataCode> KnowledgeDb::iataCodesFromName(QStringView name)
 {
     const auto fragments = splitToFragments(name);
     QStringList normalizedFragments;
     normalizedFragments.reserve(fragments.size());
     std::transform(fragments.begin(), fragments.end(), std::back_inserter(normalizedFragments), [](const auto &s) { return normalizeFragment(s); });
 
-    std::vector<IataCode> codes, candidates;
+    std::vector<IataCode> codes;
+    std::vector<IataCode> candidates;
     iataCodeForNameFragments(normalizedFragments, codes);
 
     // try again, with alternative translitarations of e.g. umlauts replaced
@@ -221,7 +224,7 @@ std::vector<KnowledgeDb::IataCode> KnowledgeDb::iataCodesFromName(const QString
 
     // check if the name contained the IATA code as disambiguation already
     const auto code = iataCodeForIataCodeFragment(fragments);
-    if (code.isValid()) {
+    if (code.isValid() && std::find(codes.begin(), codes.end(), code) != codes.end()) {
         return {code};
     }
 
@@ -238,44 +241,4 @@ std::vector<KnowledgeDb::IataCode> KnowledgeDb::iataCodesFromName(const QString
     return codes;
 }
 
-KnowledgeDb::IataCode KnowledgeDb::iataCodeFromName(const QString &name)
-{
-    const auto fragments = splitToFragments(name);
-    QStringList normalizedFragments;
-    normalizedFragments.reserve(fragments.size());
-    std::transform(fragments.begin(), fragments.end(), std::back_inserter(normalizedFragments), [](const auto &s) { return normalizeFragment(s); });
-
-    std::vector<IataCode> codes;
-    iataCodeForNameFragments(normalizedFragments, codes);
-    if (codes.size() == 1) {
-        return codes[0];
-    }
-    codes.clear();
-
-    // try again, with alternative translitarations of e.g. umlauts replaced
-    applyTransliterations(normalizedFragments);
-    iataCodeForNameFragments(normalizedFragments, codes);
-    if (codes.size() == 1) {
-        return codes[0];
-    }
-    codes.clear();
-
-    // check if the name contained the IATA code as disambiguation already
-    const auto code = iataCodeForIataCodeFragment(fragments);
-    if (code.isValid()) {
-        return {code};
-    }
-
-    // attempt to cut off possibly confusing fancy terminal names
-    auto it = std::find(normalizedFragments.begin(), normalizedFragments.end(), QStringLiteral("terminal"));
-    if (it != normalizedFragments.end()) {
-        normalizedFragments.erase(it, normalizedFragments.end());
-        iataCodeForNameFragments(normalizedFragments, codes);
-    }
-    if (codes.size() == 1) {
-        return codes[0];
-    }
-    return {};
-}
-
 }
