@@ -7,6 +7,7 @@
 #include "mergeutil.h"
 #include "logging.h"
 #include "compare-logging.h"
+#include "locationutil.h"
 #include "stringutil.h"
 #include "sortutil.h"
 
@@ -39,11 +40,8 @@ static bool equalAndPresent(const QString &lhs, const QString &rhs, Qt::CaseSens
 {
     return !lhs.isEmpty() && (lhs.compare(rhs, caseSensitive) == 0);
 }
-static bool equalAndPresent(const QDate &lhs, const QDate &rhs)
-{
-    return lhs.isValid() && lhs == rhs;
-}
-static bool equalAndPresent(const QDateTime &lhs, const QDateTime &rhs)
+template <typename T>
+static bool equalAndPresent(const T &lhs, const T &rhs)
 {
     return lhs.isValid() && lhs == rhs;
 }
@@ -53,7 +51,8 @@ static bool conflictIfPresent(const QString &lhs, const QString &rhs, Qt::CaseSe
 {
     return !lhs.isEmpty() && !rhs.isEmpty() && lhs.compare(rhs, caseSensitive) != 0;
 }
-static bool conflictIfPresent(const QDateTime &lhs, const QDateTime &rhs)
+template <typename T>
+static bool conflictIfPresent(const T &lhs, const T &rhs)
 {
     return lhs.isValid() && rhs.isValid() && lhs != rhs;
 }
@@ -103,7 +102,7 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
             return false;
         }
 
-        // one side is a minimal cancelation, matches the reservation number and has a plausible modification time
+        // one side is a minimal cancellation, matches the reservation number and has a plausible modification time
         // in this case don't bother comparing content (which will fail), we accept this directly
         if (isMinimalCancelationFor(lhs, rhsRes) || isMinimalCancelationFor(rhs, lhsRes)) {
             return true;
@@ -315,8 +314,8 @@ static bool isSameTrainTrip(const TrainTrip &lhs, const TrainTrip &rhs)
         return false;
     }
 
-    // for unbound tickets, comparing the line number below wont help
-    // so we have to use the slightly less robust location comparisson
+    // for unbound tickets, comparing the line number below won't help
+    // so we have to use the slightly less robust location comparison
     if (!lhs.departureTime().isValid() && !rhs.departureTime().isValid()) {
         qCDebug(CompareLog) << "unbound trip" << lhs.departureStation().name() << rhs.departureStation().name() << lhs.arrivalStation().name() << rhs.arrivalStation().name();
         return lhs.departureStation().name() == rhs.departureStation().name() && lhs.arrivalStation().name() == rhs.arrivalStation().name();
@@ -427,8 +426,14 @@ bool MergeUtil::isSamePerson(const Person& lhs, const Person& rhs)
 
 static bool isSameEvent(const Event &lhs, const Event &rhs)
 {
-    return equalAndPresent(lhs.name(), rhs.name())
-        && equalAndPresent(lhs.startDate(), rhs.startDate());
+    if (!equalAndPresent(lhs.startDate(), rhs.startDate())) {
+        return false;
+    }
+
+    // event names can contain additional qualifiers, like for Adult/Child tickets,
+    // those don't change the event though
+    const auto namePrefix = StringUtil::prefixSimilarity(lhs.name(), rhs.name());
+    return namePrefix == 1.0f || (namePrefix > 0.65f && LocationUtil::isSameLocation(lhs.location(), rhs.location(), LocationUtil::Exact));
 }
 
 static bool isSameRentalCar(const RentalCar &lhs, const RentalCar &rhs)
@@ -442,65 +447,10 @@ static bool isSameTaxiTrip(const Taxi &lhs, const Taxi &rhs)
     return lhs.name() == rhs.name();
 }
 
-static bool containsNonAscii(const QString &s)
-{
-    for (const auto c : s) {
-        if (c.row() != 0 || c.cell() > 127) {
-            return true;
-        }
-    }
-
-    return false;
-}
-
-static bool isMixedCase(const QString &s)
-{
-    const auto upperCount = std::count_if(s.begin(), s.end(), [](auto c) { return c.isUpper(); });
-    return upperCount != s.size() && upperCount != 0;
-}
-
-/** Assuming both sides refer to the same thing, this tries to find the "better" one. */
-static QString mergeString(const QString &lhs, const QString &rhs)
-{
-    // prefer the one that exists at all
-    if (lhs.isEmpty()) {
-        return rhs;
-    }
-    if (rhs.isEmpty()) {
-        return lhs;
-    }
-
-    // prefer Unicode over ASCII normalization
-    const auto lhsNonAscii = containsNonAscii(lhs);
-    const auto rhsNonAscii = containsNonAscii(rhs);
-    if (lhsNonAscii && !rhsNonAscii) {
-        return lhs;
-    }
-    if (!lhsNonAscii && rhsNonAscii) {
-        return rhs;
-    }
-
-    // prefer better casing
-    const auto lhsMixedCase = isMixedCase(lhs);
-    const auto rhsMixedCase = isMixedCase(rhs);
-    if (lhsMixedCase && !rhsMixedCase) {
-        return lhs;
-    }
-    if (!lhsMixedCase && rhsMixedCase) {
-        return rhs;
-    }
-
-    // prefer longer == more detailed version
-    if (rhs.size() < lhs.size()) {
-        return lhs;
-    }
-    return rhs;
-}
-
 static Airline mergeValue(const Airline &lhs, const Airline &rhs)
 {
     auto a = JsonLdDocument::apply(lhs, rhs).value<Airline>();
-    a.setName(mergeString(lhs.name(), rhs.name()));
+    a.setName(StringUtil::betterString(lhs.name(), rhs.name()).toString());
     return a;
 }
 
@@ -513,9 +463,9 @@ static QDateTime mergeValue(const QDateTime &lhs, const QDateTime &rhs)
 static Person mergeValue(const Person &lhs, const Person &rhs)
 {
     auto p = JsonLdDocument::apply(lhs, rhs).value<Person>();
-    p.setFamilyName(mergeString(lhs.familyName(), rhs.familyName()));
-    p.setGivenName(mergeString(lhs.givenName(), rhs.givenName()));
-    p.setName(mergeString(lhs.name(), rhs.name()));
+    p.setFamilyName(StringUtil::betterString(lhs.familyName(), rhs.familyName()).toString());
+    p.setGivenName(StringUtil::betterString(lhs.givenName(), rhs.givenName()).toString());
+    p.setName(StringUtil::betterString(lhs.name(), rhs.name()).toString());
     return p;
 }
 
