@@ -8,6 +8,11 @@
 
 #include <KItinerary/ExtractorFilter>
 
+#include <QQmlEngine>
+
+#include <private/qv4arraybuffer_p.h>
+#include <private/qv4engine_p.h>
+
 using namespace KItinerary;
 
 ExtractorDocumentNode BinaryDocumentProcessor::createNodeFromData(const QByteArray &encodedData) const
@@ -21,3 +26,8 @@ bool BinaryDocumentProcessor::matches(const ExtractorFilter &filter, const Extra
 {
     return filter.matches(QString::fromLatin1(node.content<QByteArray>()));
 }
+
+QJSValue BinaryDocumentProcessor::contentToScriptValue(const ExtractorDocumentNode &node, QJSEngine *engine) const
+{
+    return QJSValue(engine->handle(), engine->handle()->newArrayBuffer(node.content<QByteArray>())->asReturnedValue());
+}
