@@ -235,6 +235,7 @@ function parseSecutixPdf(pdf, node, triggerNode)
     // see https://community.kde.org/KDE_PIM/KItinerary/SNCF_Barcodes#SNCF_Secutix_Tickets
     var res = JsonLd.newTrainReservation();
     var code = ByteArray.decodeLatin1(triggerNode.content.slice(260));
+    res.reservationFor.provider.identifier = 'uic:' + code.substr(4, 4);
     res.reservationNumber = code.substr(8, 9);
     res.reservationFor.departureStation.name = code.substr(17, 5);
     res.reservationFor.departureStation.identifier = "sncf:" + code.substr(17, 5);
@@ -250,7 +251,7 @@ function parseSecutixPdf(pdf, node, triggerNode)
     var pnr = text.match(res.reservationNumber + '[^\n]* ([A-Z0-9]{6})\n');
     var layoutVersion = 1;
     if (!pnr) {
-        pnr = text.match(/PAO\s*:\s*([A-Z0-9]{6})\n/);
+        pnr = text.match(/(?:PAO|REF)\s*:\s*([A-Z0-9]{6,8})\n/);
         layoutVersion = 2;
     }
     res.reservationNumber = pnr[1];
@@ -262,6 +263,9 @@ function parseSecutixPdf(pdf, node, triggerNode)
 
     reservations[0].reservationFor.departureStation.identifier = res.reservationFor.departureStation.identifier;
     reservations[reservations.length - 1].reservationFor.arrivalStation.identifier = res.reservationFor.arrivalStation.identifier;
+    for (r of reservations) {
+        r.reservationFor.provider = res.reservationFor.provider;
+    }
 
     return reservations;
 }
