@@ -15,18 +15,19 @@ function parseSsbTicket(ssb, node) {
     res.reservationFor.arrivalStation.identifier = "benerail:" + ssb.type1ArrivalStationAlpha;
     res.reservationFor.departureDay = ssb.type1DepartureDay(node.contextDateTime)
     res.reservationFor.trainNumber = "THA " + ssb.type1TrainNumber.trim();
+    res.reservationFor.provider.identifier = "uic:" + ssb.issuerCode;
     res.reservedTicket.ticketedSeat.seatingType = ssb.classOfTravel;
     res.reservedTicket.ticketedSeat.seatSection = ssb.type1CoachNumber;
     res.reservedTicket.ticketedSeat.seatNumber = ssb.type1SeatNumber;
     res.reservationNumber = ssb.tcn;
-    res.reservedTicket.ticketToken = "aztecbin:" + Barcode.toBase64(ssb.rawData);
+    res.reservedTicket.ticketToken = "aztecbin:" + ByteArray.toBase64(ssb.rawData);
     return res;
 }
 
 function parseReservation(html, node) {
     var tokenElem = html.eval('//table[@class="qrcode"]//img')[0];
     var token = tokenElem.attribute("src").match(/barcode\/tAZTEC\/.*\/nBinary\/v(.*)\/barcode.gif/);
-    var res = parseSsbTicket(Barcode.decodeEraSsbTicket(Barcode.fromBase64(token[1])), node);
+    var res = parseSsbTicket(Barcode.decodeEraSsbTicket(ByteArray.fromBase64(token[1])), node);
 
     var subtitle = html.eval('//table[@class="subtitle"]');
     var ref = subtitle[0].recursiveContent.match(/(\d{2}.\d{2}.\d{4})[\s\S]*([A-Z0-9]{6})/);
