@@ -37,7 +37,7 @@ function parsePdf(pdf) {
         var offset = 0;
         for (var j = 0; j < images.length; ++j) {
             var barcode = Barcode.decodeAztecBinary(images[j]);
-            var barcodeB64 = Barcode.toBase64(barcode);
+            var barcodeB64 = barcode ? ByteArray.toBase64(barcode) : undefined;
             if (!barcodeB64)
                 continue;
 
@@ -53,17 +53,21 @@ function parsePdf(pdf) {
             }
 
             // see https://community.kde.org/KDE_PIM/KItinerary/Trenitalia_Barcode
-            var ssb = Barcode.decodeEraSsbTicket(barcode)
+            const ssb = Barcode.decodeEraSsbTicket(barcode)
             personalRes.reservationFor.departureStation.identifier = "uic:" + (ssb.departureStationNum % 10000000)
             if (ssb.departureStationNum != ssb.arrivalStationNum) {
                 personalRes.reservationFor.arrivalStation.identifier = "uic:" + (ssb.arrivalStationNum % 10000000)
             }
+            personalRes.reservationFor.provider.identifier = "uic:" + ssb.issuerCode;
+            if (ssb.customerNumber > 0) {
+                personalRes.programMembershipUsed.membershipNumber = ssb.customerNumber;
+                personalRes.programMembershipUsed.programName = "CartaFRECCIA";
+            }
 
-            var bitArray = Barcode.toBitArray(barcode);
-            var seatNum = bitArray.readNumberMSB(31*8 + 2, 7);
+            const seatNum = ssb.readNumber(31*8 + 2, 7);
             if (seatNum > 0) {
                 personalRes.reservedTicket.ticketedSeat.seatNumber = "" + seatNum;
-                var seatCol = bitArray.readNumberMSB(32*8 + 3, 4);
+                const seatCol = ssb.readNumber(32*8 + 3, 4);
                 if (seatCol > 0) {
                     personalRes.reservedTicket.ticketedSeat.seatNumber += seatCol.toString(16).toUpperCase();
                 }
